@@ -17,11 +17,11 @@ module Fog
 
           request(
             :headers => {
-              'Authorization' => "Basic #{@auth_encord}"
+              'Authorization' => "Basic #{@auth_encode}"
             },
             :expects  => 202,
             :method => 'POST',
-            :path => "#{Fog::SakuraCloud::SAKURACLOUD_API_ENDPOINT}/internet",
+            :path => "#{Fog::SakuraCloud.build_endpoint(@api_zone)}/internet",
             :body => Fog::JSON.encode(body)
           )
         end
