@@ -13,11 +13,11 @@ module Fog
 
           request(
             :headers => {
-              'Authorization' => "Basic #{@auth_encord}"
+              'Authorization' => "Basic #{@auth_encode}"
             },
             :expects  => 201,
             :method => 'POST',
-            :path => "#{Fog::SakuraCloud::SAKURACLOUD_API_ENDPOINT}/switch",
+            :path => "#{Fog::SakuraCloud.build_endpoint(@api_zone)}/switch",
             :body => Fog::JSON.encode(body)
           )
         end
