@@ -7,11 +7,11 @@ module Fog
         def delete_disk( id )
           request(
             :headers => {
-              'Authorization' => "Basic #{@auth_encord}"
+              'Authorization' => "Basic #{@auth_encode}"
             },
             :expects  => [200],
             :method => 'DELETE',
-            :path => "#{Fog::SakuraCloud::SAKURACLOUD_API_ENDPOINT}/disk/#{id}"
+            :path => "#{Fog::SakuraCloud.build_endpoint(@api_zone)}/disk/#{id}"
           )
         end
       end # Real
