@@ -2,12 +2,13 @@
 ENV['FOG_RC'] = ENV['FOG_RC'] || File.expand_path('../.fog', __FILE__)
 
 ## From fog-core
-require 'fog/test_helpers/formats_helper'
+require 'fog/test_helpers'
+require 'fog/sakuracloud'
 
-## From fog submodule
-require File.expand_path('../../fog/tests/helper', __FILE__)
-helpers = Dir.glob(File.expand_path('../../', __FILE__) + '/fog/tests/helpers/**/*.rb')
-helpers.map {|h| load h}
+if ENV['CI']
+  Fog.credentials[:sakuracloud_api_token]        = 'dummy_token'
+  Fog.credentials[:sakuracloud_api_token_secret] = 'dummy_secret'
+end
 
 ## SakuraCloud Helpers
 def sakuracloud_volume_service
